@@ -13,7 +13,7 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from tempest_lib.common.utils import data_utils
+from tempest.lib.common.utils import data_utils
 import testtools
 
 from ec2api.tests.functional import base
@@ -72,6 +72,7 @@ class ImageTest(base.EC2TestCase):
         self.assertEqual(1, len(data['Images']))
         self.assertEqual(image_id, data['Images'][0]['ImageId'])
 
+    @testtools.skipUnless(CONF.aws.image_id, "Image id is not defined")
     def test_check_image_operations_negative(self):
         # NOTE(andrey-mp): image_id is a public image created by admin
         image_id = CONF.aws.image_id
@@ -334,7 +335,5 @@ class ImageRegisterTest(base.EC2TestCase):
         self.get_image_waiter().wait_available(image_id)
 
         self.client.deregister_image(ImageId=image_id)
-        self.assertRaises('InvalidAMIID.NotFound',
-                          self.client.describe_images,
-                          ImageIds=[image_id])
         self.cancelResourceCleanUp(image_clean)
+        self.get_image_waiter().wait_delete(image_id)
